(add-hook 'ilisp-load-hook
	  (function
	   (lambda ()
	     (setq cltl2-root-url "/usr/share/doc/cltl/")
	     (defkey-ilisp [(shift f1)] 'cltl2-lookup))))

;;; also just set it so it can be used without ilisp
(setq cltl2-root-url "/usr/share/doc/cltl/")
